summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorSebastian Dröge <sebastian@centricular.com>2018-05-04 16:46:00 +0200
committerSebastian Dröge <sebastian@centricular.com>2018-05-04 16:46:00 +0200
commit10b7b13732b699d7dd9dfa1970733068c904cfba (patch)
tree88530aac3435b76b13e033d600cdf565bc4178b8 /tests
parente34d4e9bf469b8b01f02383f1875c89941d3e323 (diff)
downloadgstreamer-plugins-bad-10b7b13732b699d7dd9dfa1970733068c904cfba.tar.gz
videoaggregator: Rename ignore-eos pad property to repeat-after-eos
What it does is to repeat the last frame forever after EOS, it does not literally ignore EOS.
Diffstat (limited to 'tests')
-rw-r--r--tests/check/elements/compositor.c8
-rw-r--r--tests/examples/playout.c4
2 files changed, 6 insertions, 6 deletions
diff --git a/tests/examples/playout.c b/tests/examples/playout.c
index 07048d83e..7dcadb6d4 100644
--- a/tests/examples/playout.c
+++ b/tests/examples/playout.c
@@ -873,9 +873,9 @@ playout_app_activate_item (PlayoutItem * item)
/* If this is not the last item, on EOS, continue to aggregate using the
* last buffer till the pad is released */
if (item->app->play_queue->len != (item->app->play_queue_current + 2))
- g_object_set (sinkpad, "ignore-eos", TRUE, NULL);
+ g_object_set (sinkpad, "repeat-after-eos", TRUE, NULL);
else
- GST_DEBUG ("%s: last item, not setting ignore-eos", item->fn);
+ GST_DEBUG ("%s: last item, not setting repeat-after-eos", item->fn);
gst_pad_link (item->video_pad, sinkpad);
if (app->elapsed_duration > 0) {
diff --git a/tests/check/elements/compositor.c b/tests/check/elements/compositor.c
index 95c518f04..34525e98c 100644
--- a/tests/check/elements/compositor.c
+++ b/tests/check/elements/compositor.c
@@ -1765,7 +1765,7 @@ _buffer_recvd (GstElement * appsink, gint * buffers_recvd)
return GST_FLOW_OK;
}
-GST_START_TEST (test_ignore_eos)
+GST_START_TEST (test_repeat_after_eos)
{
gboolean res;
gint buffers_recvd;
@@ -1793,9 +1793,9 @@ GST_START_TEST (test_ignore_eos)
ck_assert_msg (res == TRUE, "Could not link compositor with appsink");
srcpad = gst_element_get_static_pad (src, "src");
sinkpad = gst_element_get_request_pad (compositor, "sink_%u");
/* When "ignore-eos" is set, compositor will keep sending the last buffer even
* after EOS, so we will receive more buffers than we sent. */
- g_object_set (sinkpad, "ignore-eos", TRUE, NULL);
+ g_object_set (sinkpad, "repeat-after-eos", TRUE, NULL);
link_res = gst_pad_link (srcpad, sinkpad);
ck_assert_msg (GST_PAD_LINK_SUCCESSFUL (link_res), "videotestsrc -> "
"compositor pad link failed: %i", link_res);
@@ -2099,7 +2099,7 @@ compositor_suite (void)
tcase_add_test (tc_chain, test_flush_start_flush_stop);
tcase_add_test (tc_chain, test_segment_base_handling);
tcase_add_test (tc_chain, test_obscured_skipped);
- tcase_add_test (tc_chain, test_ignore_eos);
+ tcase_add_test (tc_chain, test_repeat_after_eos);
tcase_add_test (tc_chain, test_pad_z_order);
tcase_add_test (tc_chain, test_pad_numbering);
tcase_add_test (tc_chain, test_start_time_zero_live_drop_0);
@@ -1793,9 +1793,9 @@ GST_START_TEST (test_ignore_eos)
srcpad = gst_element_get_static_pad (src, "src");
sinkpad = gst_element_get_request_pad (compositor, "sink_%u");
- /* When "ignore-eos" is set, compositor will keep sending the last buffer even
+ /* When "repeat-after-eos" is set, compositor will keep sending the last buffer even
* after EOS, so we will receive more buffers than we sent. */